# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from phrase_api.configuration import Configuration


class GlossaryTermUpdateParameters(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'term': 'str',
        'description': 'str',
        'translatable': 'bool',
        'case_sensitive': 'bool'
    }

    attribute_map = {
        'term': 'term',
        'description': 'description',
        'translatable': 'translatable',
        'case_sensitive': 'case_sensitive'
    }

    def __init__(self, term=None, description=None, translatable=None, case_sensitive=None, local_vars_configuration=None):  # noqa: E501
        """GlossaryTermUpdateParameters - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._term = None
        self._description = None
        self._translatable = None
        self._case_sensitive = None
        self.discriminator = None

        if term is not None:
            self.term = term
        if description is not None:
            self.description = description
        if translatable is not None:
            self.translatable = translatable
        if case_sensitive is not None:
            self.case_sensitive = case_sensitive

    @property
    def term(self):
        """Gets the term of this GlossaryTermUpdateParameters.  # noqa: E501

        Glossary term  # noqa: E501

        :return: The term of this GlossaryTermUpdateParameters.  # noqa: E501
        :rtype: str
        """
        return self._term

    @term.setter
    def term(self, term):
        """Sets the term of this GlossaryTermUpdateParameters.

        Glossary term  # noqa: E501

        :param term: The term of this GlossaryTermUpdateParameters.  # noqa: E501
        :type: str
        """

        self._term = term

    @property
    def description(self):
        """Gets the description of this GlossaryTermUpdateParameters.  # noqa: E501

        Description of term  # noqa: E501

        :return: The description of this GlossaryTermUpdateParameters.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this GlossaryTermUpdateParameters.

        Description of term  # noqa: E501

        :param description: The description of this GlossaryTermUpdateParameters.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def translatable(self):
        """Gets the translatable of this GlossaryTermUpdateParameters.  # noqa: E501

        Indicates whether the term should be used for all languages or can be translated  # noqa: E501

        :return: The translatable of this GlossaryTermUpdateParameters.  # noqa: E501
        :rtype: bool
        """
        return self._translatable

    @translatable.setter
    def translatable(self, translatable):
        """Sets the translatable of this GlossaryTermUpdateParameters.

        Indicates whether the term should be used for all languages or can be translated  # noqa: E501

        :param translatable: The translatable of this GlossaryTermUpdateParameters.  # noqa: E501
        :type: bool
        """

        self._translatable = translatable

    @property
    def case_sensitive(self):
        """Gets the case_sensitive of this GlossaryTermUpdateParameters.  # noqa: E501

        Indicates whether the term is case sensitive  # noqa: E501

        :return: The case_sensitive of this GlossaryTermUpdateParameters.  # noqa: E501
        :rtype: bool
        """
        return self._case_sensitive

    @case_sensitive.setter
    def case_sensitive(self, case_sensitive):
        """Sets the case_sensitive of this GlossaryTermUpdateParameters.

        Indicates whether the term is case sensitive  # noqa: E501

        :param case_sensitive: The case_sensitive of this GlossaryTermUpdateParameters.  # noqa: E501
        :type: bool
        """

        self._case_sensitive = case_sensitive

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GlossaryTermUpdateParameters):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GlossaryTermUpdateParameters):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import phrase_api
from phrase_api.models.space import Space  # noqa: E501
from phrase_api.rest import ApiException

class TestSpace(unittest.TestCase):
    """Space unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Space
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = phrase_api.models.space.Space()  # noqa: E501
        if include_optional :
            return Space(
                id = '0', 
                name = '0', 
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                projects_count = 56, 
                projects = [
                    {"id":"abcd1234cdef1234abcd1234cdef1234","name":"My Android Project","slug":"android_project","main_format":"xml","project_image_url":"http://assets.example.com/project.png","account":"account","space":"space","created_at":"2015-01-28T09:52:53Z","updated_at":"2015-01-28T09:52:53Z"}
                    ]
            )
        else :
            return Space(
        )

    def testSpace(self):
        """Test Space"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import phrase_api
from phrase_api.models.order_create_parameters import OrderCreateParameters  # noqa: E501
from phrase_api.rest import ApiException

class TestOrderCreateParameters(unittest.TestCase):
    """OrderCreateParameters unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test OrderCreateParameters
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = phrase_api.models.order_create_parameters.OrderCreateParameters()  # noqa: E501
        if include_optional :
            return OrderCreateParameters(
                branch = 'my-feature-branch', 
                name = 'Welcome message translations', 
                lsp = 'textmaster', 
                source_locale_id = 'abcd1234abcd1234abcd1234abcd1234', 
                target_locale_ids = ["1234abcd1234abcd1234abcd1234abcd","abcd1234abcd1234abcd1234abcd1234"], 
                translation_type = 'premium', 
                tag = 'my-awesome-feature', 
                message = 'Please make everything sound really nice :)', 
                styleguide_id = '1234abcd1234abcd1234abcd1234abcd', 
                unverify_translations_upon_delivery = True, 
                include_untranslated_keys = True, 
                include_unverified_translations = True, 
                category = 'C021', 
                quality = True, 
                priority = True
            )
        else :
            return OrderCreateParameters(
        )

    def testOrderCreateParameters(self):
        """Test OrderCreateParameters"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from phrase_api.configuration import Configuration


class UploadCreateParameters(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'branch': 'str',
        'file': 'file',
        'file_format': 'str',
        'locale_id': 'str',
        'tags': 'str',
        'update_translations': 'bool',
        'update_descriptions': 'bool',
        'convert_emoji': 'bool',
        'skip_upload_tags': 'bool',
        'skip_unverification': 'bool',
        'file_encoding': 'str',
        'locale_mapping': 'object',
        'format_options': 'object',
        'autotranslate': 'bool',
        'mark_reviewed': 'bool'
    }

    attribute_map = {
        'branch': 'branch',
        'file': 'file',
        'file_format': 'file_format',
        'locale_id': 'locale_id',
        'tags': 'tags',
        'update_translations': 'update_translations',
        'update_descriptions': 'update_descriptions',
        'convert_emoji': 'convert_emoji',
        'skip_upload_tags': 'skip_upload_tags',
        'skip_unverification': 'skip_unverification',
        'file_encoding': 'file_encoding',
        'locale_mapping': 'locale_mapping',
        'format_options': 'format_options',
        'autotranslate': 'autotranslate',
        'mark_reviewed': 'mark_reviewed'
    }

    def __init__(self, branch=None, file=None, file_format=None, locale_id=None, tags=None, update_translations=None, update_descriptions=None, convert_emoji=None, skip_upload_tags=None, skip_unverification=None, file_encoding=None, locale_mapping=None, format_options=None, autotranslate=None, mark_reviewed=None, local_vars_configuration=None):  # noqa: E501
        """UploadCreateParameters - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._branch = None
        self._file = None
        self._file_format = None
        self._locale_id = None
        self._tags = None
        self._update_translations = None
        self._update_descriptions = None
        self._convert_emoji = None
        self._skip_upload_tags = None
        self._skip_unverification = None
        self._file_encoding = None
        self._locale_mapping = None
        self._format_options = None
        self._autotranslate = None
        self._mark_reviewed = None
        self.discriminator = None

        if branch is not None:
            self.branch = branch
        if file is not None:
            self.file = file
        if file_format is not None:
            self.file_format = file_format
        if locale_id is not None:
            self.locale_id = locale_id
        if tags is not None:
            self.tags = tags
        if update_translations is not None:
            self.update_translations = update_translations
        if update_descriptions is not None:
            self.update_descriptions = update_descriptions
        if convert_emoji is not None:
            self.convert_emoji = convert_emoji
        if skip_upload_tags is not None:
            self.skip_upload_tags = skip_upload_tags
        if skip_unverification is not None:
            self.skip_unverification = skip_unverification
        if file_encoding is not None:
            self.file_encoding = file_encoding
        if locale_mapping is not None:
            self.locale_mapping = locale_mapping
        if format_options is not None:
            self.format_options = format_options
        if autotranslate is not None:
            self.autotranslate = autotranslate
        if mark_reviewed is not None:
            self.mark_reviewed = mark_reviewed

    @property
    def branch(self):
        """Gets the branch of this UploadCreateParameters.  # noqa: E501

        specify the branch to use  # noqa: E501

        :return: The branch of this UploadCreateParameters.  # noqa: E501
        :rtype: str
        """
        return self._branch

    @branch.setter
    def branch(self, branch):
        """Sets the branch of this UploadCreateParameters.

        specify the branch to use  # noqa: E501

        :param branch: The branch of this UploadCreateParameters.  # noqa: E501
        :type: str
        """

        self._branch = branch

    @property
    def file(self):
        """Gets the file of this UploadCreateParameters.  # noqa: E501

        File to be imported  # noqa: E501

        :return: The file of this UploadCreateParameters.  # noqa: E501
        :rtype: file
        """
        return self._file

    @file.setter
    def file(self, file):
        """Sets the file of this UploadCreateParameters.

        File to be imported  # noqa: E501

        :param file: The file of this UploadCreateParameters.  # noqa: E501
        :type: file
        """

        self._file = file

    @property
    def file_format(self):
        """Gets the file_format of this UploadCreateParameters.  # noqa: E501

        File format. Auto-detected when possible and not specified.  # noqa: E501

        :return: The file_format of this UploadCreateParameters.  # noqa: E501
        :rtype: str
        """
        return self._file_format

    @file_format.setter
    def file_format(self, file_format):
        """Sets the file_format of this UploadCreateParameters.

        File format. Auto-detected when possible and not specified.  # noqa: E501

        :param file_format: The file_format of this UploadCreateParameters.  # noqa: E501
        :type: str
        """

        self._file_format = file_format

    @property
    def locale_id(self):
        """Gets the locale_id of this UploadCreateParameters.  # noqa: E501

        Locale of the file's content. Can be the name or public id of the locale. Preferred is the public id.  # noqa: E501

        :return: The locale_id of this UploadCreateParameters.  # noqa: E501
        :rtype: str
        """
        return self._locale_id

    @locale_id.setter
    def locale_id(self, locale_id):
        """Sets the locale_id of this UploadCreateParameters.

        Locale of the file's content. Can be the name or public id of the locale. Preferred is the public id.  # noqa: E501

        :param locale_id: The locale_id of this UploadCreateParameters.  # noqa: E501
        :type: str
        """

        self._locale_id = locale_id

    @property
    def tags(self):
        """Gets the tags of this UploadCreateParameters.  # noqa: E501

        List of tags separated by comma to be associated with the new keys contained in the upload.  # noqa: E501

        :return: The tags of this UploadCreateParameters.  # noqa: E501
        :rtype: str
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this UploadCreateParameters.

        List of tags separated by comma to be associated with the new keys contained in the upload.  # noqa: E501

        :param tags: The tags of this UploadCreateParameters.  # noqa: E501
        :type: str
        """

        self._tags = tags

    @property
    def update_translations(self):
        """Gets the update_translations of this UploadCreateParameters.  # noqa: E501

        Indicates whether existing translations should be updated with the file content.  # noqa: E501

        :return: The update_translations of this UploadCreateParameters.  # noqa: E501
        :rtype: bool
        """
        return self._update_translations

    @update_translations.setter
    def update_translations(self, update_translations):
        """Sets the update_translations of this UploadCreateParameters.

        Indicates whether existing translations should be updated with the file content.  # noqa: E501

        :param update_translations: The update_translations of this UploadCreateParameters.  # noqa: E501
        :type: bool
        """

        self._update_translations = update_translations

    @property
    def update_descriptions(self):
        """Gets the update_descriptions of this UploadCreateParameters.  # noqa: E501

        Existing key descriptions will be updated with the file content. Empty descriptions overwrite existing descriptions.  # noqa: E501

        :return: The update_descriptions of this UploadCreateParameters.  # noqa: E501
        :rtype: bool
        """
        return self._update_descriptions

    @update_descriptions.setter
    def update_descriptions(self, update_descriptions):
        """Sets the update_descriptions of this UploadCreateParameters.

        Existing key descriptions will be updated with the file content. Empty descriptions overwrite existing descriptions.  # noqa: E501

        :param update_descriptions: The update_descriptions of this UploadCreateParameters.  # noqa: E501
        :type: bool
        """

        self._update_descriptions = update_descriptions

    @property
    def convert_emoji(self):
        """Gets the convert_emoji of this UploadCreateParameters.  # noqa: E501

        This option is obsolete. Providing the option will cause a bad request error.  # noqa: E501

        :return: The convert_emoji of this UploadCreateParameters.  # noqa: E501
        :rtype: bool
        """
        return self._convert_emoji

    @convert_emoji.setter
    def convert_emoji(self, convert_emoji):
        """Sets the convert_emoji of this UploadCreateParameters.

        This option is obsolete. Providing the option will cause a bad request error.  # noqa: E501

        :param convert_emoji: The convert_emoji of this UploadCreateParameters.  # noqa: E501
        :type: bool
        """

        self._convert_emoji = convert_emoji

    @property
    def skip_upload_tags(self):
        """Gets the skip_upload_tags of this UploadCreateParameters.  # noqa: E501

        Indicates whether the upload should not create upload tags.  # noqa: E501

        :return: The skip_upload_tags of this UploadCreateParameters.  # noqa: E501
        :rtype: bool
        """
        return self._skip_upload_tags

    @skip_upload_tags.setter
    def skip_upload_tags(self, skip_upload_tags):
        """Sets the skip_upload_tags of this UploadCreateParameters.

        Indicates whether the upload should not create upload tags.  # noqa: E501

        :param skip_upload_tags: The skip_upload_tags of this UploadCreateParameters.  # noqa: E501
        :type: bool
        """

        self._skip_upload_tags = skip_upload_tags

    @property
    def skip_unverification(self):
        """Gets the skip_unverification of this UploadCreateParameters.  # noqa: E501

        Indicates whether the upload should unverify updated translations.  # noqa: E501

        :return: The skip_unverification of this UploadCreateParameters.  # noqa: E501
        :rtype: bool
        """
        return self._skip_unverification

    @skip_unverification.setter
    def skip_unverification(self, skip_unverification):
        """Sets the skip_unverification of this UploadCreateParameters.

        Indicates whether the upload should unverify updated translations.  # noqa: E501

        :param skip_unverification: The skip_unverification of this UploadCreateParameters.  # noqa: E501
        :type: bool
        """

        self._skip_unverification = skip_unverification

    @property
    def file_encoding(self):
        """Gets the file_encoding of this UploadCreateParameters.  # noqa: E501

        Enforces a specific encoding on the file contents. Valid options are \"UTF-8\", \"UTF-16\" and \"ISO-8859-1\".  # noqa: E501

        :return: The file_encoding of this UploadCreateParameters.  # noqa: E501
        :rtype: str
        """
        return self._file_encoding

    @file_encoding.setter
    def file_encoding(self, file_encoding):
        """Sets the file_encoding of this UploadCreateParameters.

        Enforces a specific encoding on the file contents. Valid options are \"UTF-8\", \"UTF-16\" and \"ISO-8859-1\".  # noqa: E501

        :param file_encoding: The file_encoding of this UploadCreateParameters.  # noqa: E501
        :type: str
        """

        self._file_encoding = file_encoding

    @property
    def locale_mapping(self):
        """Gets the locale_mapping of this UploadCreateParameters.  # noqa: E501

        Optional, format specific mapping between locale names and the columns the translations to those locales are contained in.  # noqa: E501

        :return: The locale_mapping of this UploadCreateParameters.  # noqa: E501
        :rtype: object
        """
        return self._locale_mapping

    @locale_mapping.setter
    def locale_mapping(self, locale_mapping):
        """Sets the locale_mapping of this UploadCreateParameters.

        Optional, format specific mapping between locale names and the columns the translations to those locales are contained in.  # noqa: E501

        :param locale_mapping: The locale_mapping of this UploadCreateParameters.  # noqa: E501
        :type: object
        """

        self._locale_mapping = locale_mapping

    @property
    def format_options(self):
        """Gets the format_options of this UploadCreateParameters.  # noqa: E501

        Additional options available for specific formats. See our format guide for complete list.  # noqa: E501

        :return: The format_options of this UploadCreateParameters.  # noqa: E501
        :rtype: object
        """
        return self._format_options

    @format_options.setter
    def format_options(self, format_options):
        """Sets the format_options of this UploadCreateParameters.

        Additional options available for specific formats. See our format guide for complete list.  # noqa: E501

        :param format_options: The format_options of this UploadCreateParameters.  # noqa: E501
        :type: object
        """

        self._format_options = format_options

    @property
    def autotranslate(self):
        """Gets the autotranslate of this UploadCreateParameters.  # noqa: E501

        If set, translations for the uploaded language will be fetched automatically.  # noqa: E501

        :return: The autotranslate of this UploadCreateParameters.  # noqa: E501
        :rtype: bool
        """
        return self._autotranslate

    @autotranslate.setter
    def autotranslate(self, autotranslate):
        """Sets the autotranslate of this UploadCreateParameters.

        If set, translations for the uploaded language will be fetched automatically.  # noqa: E501

        :param autotranslate: The autotranslate of this UploadCreateParameters.  # noqa: E501
        :type: bool
        """

        self._autotranslate = autotranslate

    @property
    def mark_reviewed(self):
        """Gets the mark_reviewed of this UploadCreateParameters.  # noqa: E501

        Indicated whether the imported translations should be marked as reviewed. This setting is available if the review workflow (currently beta) is enabled for the project.  # noqa: E501

        :return: The mark_reviewed of this UploadCreateParameters.  # noqa: E501
        :rtype: bool
        """
        return self._mark_reviewed

    @mark_reviewed.setter
    def mark_reviewed(self, mark_reviewed):
        """Sets the mark_reviewed of this UploadCreateParameters.

        Indicated whether the imported translations should be marked as reviewed. This setting is available if the review workflow (currently beta) is enabled for the project.  # noqa: E501

        :param mark_reviewed: The mark_reviewed of this UploadCreateParameters.  # noqa: E501
        :type: bool
        """

        self._mark_reviewed = mark_reviewed

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UploadCreateParameters):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UploadCreateParameters):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import phrase_api
from phrase_api.api.screenshot_markers_api import ScreenshotMarkersApi  # noqa: E501
from phrase_api.rest import ApiException


class TestScreenshotMarkersApi(unittest.TestCase):
    """ScreenshotMarkersApi unit test stubs"""

    def setUp(self):
        self.api = phrase_api.api.screenshot_markers_api.ScreenshotMarkersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_screenshot_marker_create(self):
        """Test case for screenshot_marker_create

        Create a screenshot marker  # noqa: E501
        """
        pass

    def test_screenshot_marker_delete(self):
        """Test case for screenshot_marker_delete

        Delete a screenshot marker  # noqa: E501
        """
        pass

    def test_screenshot_marker_show(self):
        """Test case for screenshot_marker_show

        Get a single screenshot marker  # noqa: E501
        """
        pass

    def test_screenshot_marker_update(self):
        """Test case for screenshot_marker_update

        Update a screenshot marker  # noqa: E501
        """
        pass

    def test_screenshot_markers_list(self):
        """Test case for screenshot_markers_list

        List screenshot markers  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from phrase_api.configuration import Configuration


class TranslationUpdateParameters(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'branch': 'str',
        'content': 'str',
        'plural_suffix': 'str',
        'unverified': 'bool',
        'excluded': 'bool',
        'autotranslate': 'bool'
    }

    attribute_map = {
        'branch': 'branch',
        'content': 'content',
        'plural_suffix': 'plural_suffix',
        'unverified': 'unverified',
        'excluded': 'excluded',
        'autotranslate': 'autotranslate'
    }

    def __init__(self, branch=None, content=None, plural_suffix=None, unverified=None, excluded=None, autotranslate=None, local_vars_configuration=None):  # noqa: E501
        """TranslationUpdateParameters - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._branch = None
        self._content = None
        self._plural_suffix = None
        self._unverified = None
        self._excluded = None
        self._autotranslate = None
        self.discriminator = None

        if branch is not None:
            self.branch = branch
        if content is not None:
            self.content = content
        if plural_suffix is not None:
            self.plural_suffix = plural_suffix
        if unverified is not None:
            self.unverified = unverified
        if excluded is not None:
            self.excluded = excluded
        if autotranslate is not None:
            self.autotranslate = autotranslate

    @property
    def branch(self):
        """Gets the branch of this TranslationUpdateParameters.  # noqa: E501

        specify the branch to use  # noqa: E501

        :return: The branch of this TranslationUpdateParameters.  # noqa: E501
        :rtype: str
        """
        return self._branch

    @branch.setter
    def branch(self, branch):
        """Sets the branch of this TranslationUpdateParameters.

        specify the branch to use  # noqa: E501

        :param branch: The branch of this TranslationUpdateParameters.  # noqa: E501
        :type: str
        """

        self._branch = branch

    @property
    def content(self):
        """Gets the content of this TranslationUpdateParameters.  # noqa: E501

        Translation content  # noqa: E501

        :return: The content of this TranslationUpdateParameters.  # noqa: E501
        :rtype: str
        """
        return self._content

    @content.setter
    def content(self, content):
        """Sets the content of this TranslationUpdateParameters.

        Translation content  # noqa: E501

        :param content: The content of this TranslationUpdateParameters.  # noqa: E501
        :type: str
        """

        self._content = content

    @property
    def plural_suffix(self):
        """Gets the plural_suffix of this TranslationUpdateParameters.  # noqa: E501

        Plural suffix. Can be one of: zero, one, two, few, many, other. Must be specified if the key associated to the translation is pluralized.  # noqa: E501

        :return: The plural_suffix of this TranslationUpdateParameters.  # noqa: E501
        :rtype: str
        """
        return self._plural_suffix

    @plural_suffix.setter
    def plural_suffix(self, plural_suffix):
        """Sets the plural_suffix of this TranslationUpdateParameters.

        Plural suffix. Can be one of: zero, one, two, few, many, other. Must be specified if the key associated to the translation is pluralized.  # noqa: E501

        :param plural_suffix: The plural_suffix of this TranslationUpdateParameters.  # noqa: E501
        :type: str
        """

        self._plural_suffix = plural_suffix

    @property
    def unverified(self):
        """Gets the unverified of this TranslationUpdateParameters.  # noqa: E501

        Indicates whether translation is unverified. Part of the <a href=\"https://support.phrase.com/hc/en-us/articles/5784094755484\" target=\"_blank\">Advanced Workflows</a> feature.  # noqa: E501

        :return: The unverified of this TranslationUpdateParameters.  # noqa: E501
        :rtype: bool
        """
        return self._unverified

    @unverified.setter
    def unverified(self, unverified):
        """Sets the unverified of this TranslationUpdateParameters.

        Indicates whether translation is unverified. Part of the <a href=\"https://support.phrase.com/hc/en-us/articles/5784094755484\" target=\"_blank\">Advanced Workflows</a> feature.  # noqa: E501

        :param unverified: The unverified of this TranslationUpdateParameters.  # noqa: E501
        :type: bool
        """

        self._unverified = unverified

    @property
    def excluded(self):
        """Gets the excluded of this TranslationUpdateParameters.  # noqa: E501

        Indicates whether translation is excluded.  # noqa: E501

        :return: The excluded of this TranslationUpdateParameters.  # noqa: E501
        :rtype: bool
        """
        return self._excluded

    @excluded.setter
    def excluded(self, excluded):
        """Sets the excluded of this TranslationUpdateParameters.

        Indicates whether translation is excluded.  # noqa: E501

        :param excluded: The excluded of this TranslationUpdateParameters.  # noqa: E501
        :type: bool
        """

        self._excluded = excluded

    @property
    def autotranslate(self):
        """Gets the autotranslate of this TranslationUpdateParameters.  # noqa: E501

        Indicates whether the translation should be auto-translated. Responses with status 422 if provided for translation within a non-default locale or the project does not have the Autopilot feature enabled.  # noqa: E501

        :return: The autotranslate of this TranslationUpdateParameters.  # noqa: E501
        :rtype: bool
        """
        return self._autotranslate

    @autotranslate.setter
    def autotranslate(self, autotranslate):
        """Sets the autotranslate of this TranslationUpdateParameters.

        Indicates whether the translation should be auto-translated. Responses with status 422 if provided for translation within a non-default locale or the project does not have the Autopilot feature enabled.  # noqa: E501

        :param autotranslate: The autotranslate of this TranslationUpdateParameters.  # noqa: E501
        :type: bool
        """

        self._autotranslate = autotranslate

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TranslationUpdateParameters):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TranslationUpdateParameters):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from phrase_api.configuration import Configuration


class MemberUpdateParameters(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'strategy': 'str',
        'role': 'str',
        'project_ids': 'str',
        'locale_ids': 'str',
        'default_locale_codes': 'list[str]',
        'space_ids': 'list[str]',
        'permissions': 'dict(str, str)'
    }

    attribute_map = {
        'strategy': 'strategy',
        'role': 'role',
        'project_ids': 'project_ids',
        'locale_ids': 'locale_ids',
        'default_locale_codes': 'default_locale_codes',
        'space_ids': 'space_ids',
        'permissions': 'permissions'
    }

    def __init__(self, strategy=None, role=None, project_ids=None, locale_ids=None, default_locale_codes=None, space_ids=None, permissions=None, local_vars_configuration=None):  # noqa: E501
        """MemberUpdateParameters - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._strategy = None
        self._role = None
        self._project_ids = None
        self._locale_ids = None
        self._default_locale_codes = None
        self._space_ids = None
        self._permissions = None
        self.discriminator = None

        if strategy is not None:
            self.strategy = strategy
        if role is not None:
            self.role = role
        if project_ids is not None:
            self.project_ids = project_ids
        if locale_ids is not None:
            self.locale_ids = locale_ids
        if default_locale_codes is not None:
            self.default_locale_codes = default_locale_codes
        if space_ids is not None:
            self.space_ids = space_ids
        if permissions is not None:
            self.permissions = permissions

    @property
    def strategy(self):
        """Gets the strategy of this MemberUpdateParameters.  # noqa: E501

        Update strategy, can be any of set, add, remove. If provided, it will set, add or remove given spaces, projects and locale ids from users access list.  # noqa: E501

        :return: The strategy of this MemberUpdateParameters.  # noqa: E501
        :rtype: str
        """
        return self._strategy

    @strategy.setter
    def strategy(self, strategy):
        """Sets the strategy of this MemberUpdateParameters.

        Update strategy, can be any of set, add, remove. If provided, it will set, add or remove given spaces, projects and locale ids from users access list.  # noqa: E501

        :param strategy: The strategy of this MemberUpdateParameters.  # noqa: E501
        :type: str
        """

        self._strategy = strategy

    @property
    def role(self):
        """Gets the role of this MemberUpdateParameters.  # noqa: E501

        Member role, can be any of of Admin, ProjectManager, Developer, Designer, Translator  # noqa: E501

        :return: The role of this MemberUpdateParameters.  # noqa: E501
        :rtype: str
        """
        return self._role

    @role.setter
    def role(self, role):
        """Sets the role of this MemberUpdateParameters.

        Member role, can be any of of Admin, ProjectManager, Developer, Designer, Translator  # noqa: E501

        :param role: The role of this MemberUpdateParameters.  # noqa: E501
        :type: str
        """

        self._role = role

    @property
    def project_ids(self):
        """Gets the project_ids of this MemberUpdateParameters.  # noqa: E501

        List of project ids the user has access to.   # noqa: E501

        :return: The project_ids of this MemberUpdateParameters.  # noqa: E501
        :rtype: str
        """
        return self._project_ids

    @project_ids.setter
    def project_ids(self, project_ids):
        """Sets the project_ids of this MemberUpdateParameters.

        List of project ids the user has access to.   # noqa: E501

        :param project_ids: The project_ids of this MemberUpdateParameters.  # noqa: E501
        :type: str
        """

        self._project_ids = project_ids

    @property
    def locale_ids(self):
        """Gets the locale_ids of this MemberUpdateParameters.  # noqa: E501

        List of locale ids the user has access to.  # noqa: E501

        :return: The locale_ids of this MemberUpdateParameters.  # noqa: E501
        :rtype: str
        """
        return self._locale_ids

    @locale_ids.setter
    def locale_ids(self, locale_ids):
        """Sets the locale_ids of this MemberUpdateParameters.

        List of locale ids the user has access to.  # noqa: E501

        :param locale_ids: The locale_ids of this MemberUpdateParameters.  # noqa: E501
        :type: str
        """

        self._locale_ids = locale_ids

    @property
    def default_locale_codes(self):
        """Gets the default_locale_codes of this MemberUpdateParameters.  # noqa: E501

        List of default locales for the user.  # noqa: E501

        :return: The default_locale_codes of this MemberUpdateParameters.  # noqa: E501
        :rtype: list[str]
        """
        return self._default_locale_codes

    @default_locale_codes.setter
    def default_locale_codes(self, default_locale_codes):
        """Sets the default_locale_codes of this MemberUpdateParameters.

        List of default locales for the user.  # noqa: E501

        :param default_locale_codes: The default_locale_codes of this MemberUpdateParameters.  # noqa: E501
        :type: list[str]
        """

        self._default_locale_codes = default_locale_codes

    @property
    def space_ids(self):
        """Gets the space_ids of this MemberUpdateParameters.  # noqa: E501

        List of spaces the user is assigned to.  # noqa: E501

        :return: The space_ids of this MemberUpdateParameters.  # noqa: E501
        :rtype: list[str]
        """
        return self._space_ids

    @space_ids.setter
    def space_ids(self, space_ids):
        """Sets the space_ids of this MemberUpdateParameters.

        List of spaces the user is assigned to.  # noqa: E501

        :param space_ids: The space_ids of this MemberUpdateParameters.  # noqa: E501
        :type: list[str]
        """

        self._space_ids = space_ids

    @property
    def permissions(self):
        """Gets the permissions of this MemberUpdateParameters.  # noqa: E501

        Additional permissions depending on member role. Available permissions are <code>create_upload</code> and <code>review_translations</code>  # noqa: E501

        :return: The permissions of this MemberUpdateParameters.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._permissions

    @permissions.setter
    def permissions(self, permissions):
        """Sets the permissions of this MemberUpdateParameters.

        Additional permissions depending on member role. Available permissions are <code>create_upload</code> and <code>review_translations</code>  # noqa: E501

        :param permissions: The permissions of this MemberUpdateParameters.  # noqa: E501
        :type: dict(str, str)
        """

        self._permissions = permissions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MemberUpdateParameters):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MemberUpdateParameters):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from phrase_api.configuration import Configuration


class InvitationUpdateParameters(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'role': 'str',
        'project_ids': 'str',
        'locale_ids': 'str',
        'space_ids': 'list[str]',
        'team_ids': 'list[str]',
        'default_locale_codes': 'list[str]',
        'permissions': 'dict(str, str)'
    }

    attribute_map = {
        'role': 'role',
        'project_ids': 'project_ids',
        'locale_ids': 'locale_ids',
        'space_ids': 'space_ids',
        'team_ids': 'team_ids',
        'default_locale_codes': 'default_locale_codes',
        'permissions': 'permissions'
    }

    def __init__(self, role=None, project_ids=None, locale_ids=None, space_ids=None, team_ids=None, default_locale_codes=None, permissions=None, local_vars_configuration=None):  # noqa: E501
        """InvitationUpdateParameters - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._role = None
        self._project_ids = None
        self._locale_ids = None
        self._space_ids = None
        self._team_ids = None
        self._default_locale_codes = None
        self._permissions = None
        self.discriminator = None

        if role is not None:
            self.role = role
        if project_ids is not None:
            self.project_ids = project_ids
        if locale_ids is not None:
            self.locale_ids = locale_ids
        if space_ids is not None:
            self.space_ids = space_ids
        if team_ids is not None:
            self.team_ids = team_ids
        if default_locale_codes is not None:
            self.default_locale_codes = default_locale_codes
        if permissions is not None:
            self.permissions = permissions

    @property
    def role(self):
        """Gets the role of this InvitationUpdateParameters.  # noqa: E501

        Invitiation role, can be any of Manager, Developer, Translator  # noqa: E501

        :return: The role of this InvitationUpdateParameters.  # noqa: E501
        :rtype: str
        """
        return self._role

    @role.setter
    def role(self, role):
        """Sets the role of this InvitationUpdateParameters.

        Invitiation role, can be any of Manager, Developer, Translator  # noqa: E501

        :param role: The role of this InvitationUpdateParameters.  # noqa: E501
        :type: str
        """

        self._role = role

    @property
    def project_ids(self):
        """Gets the project_ids of this InvitationUpdateParameters.  # noqa: E501

        List of project ids the invited user has access to  # noqa: E501

        :return: The project_ids of this InvitationUpdateParameters.  # noqa: E501
        :rtype: str
        """
        return self._project_ids

    @project_ids.setter
    def project_ids(self, project_ids):
        """Sets the project_ids of this InvitationUpdateParameters.

        List of project ids the invited user has access to  # noqa: E501

        :param project_ids: The project_ids of this InvitationUpdateParameters.  # noqa: E501
        :type: str
        """

        self._project_ids = project_ids

    @property
    def locale_ids(self):
        """Gets the locale_ids of this InvitationUpdateParameters.  # noqa: E501

        List of locale ids the invited user has access to  # noqa: E501

        :return: The locale_ids of this InvitationUpdateParameters.  # noqa: E501
        :rtype: str
        """
        return self._locale_ids

    @locale_ids.setter
    def locale_ids(self, locale_ids):
        """Sets the locale_ids of this InvitationUpdateParameters.

        List of locale ids the invited user has access to  # noqa: E501

        :param locale_ids: The locale_ids of this InvitationUpdateParameters.  # noqa: E501
        :type: str
        """

        self._locale_ids = locale_ids

    @property
    def space_ids(self):
        """Gets the space_ids of this InvitationUpdateParameters.  # noqa: E501

        List of spaces the user is assigned to.  # noqa: E501

        :return: The space_ids of this InvitationUpdateParameters.  # noqa: E501
        :rtype: list[str]
        """
        return self._space_ids

    @space_ids.setter
    def space_ids(self, space_ids):
        """Sets the space_ids of this InvitationUpdateParameters.

        List of spaces the user is assigned to.  # noqa: E501

        :param space_ids: The space_ids of this InvitationUpdateParameters.  # noqa: E501
        :type: list[str]
        """

        self._space_ids = space_ids

    @property
    def team_ids(self):
        """Gets the team_ids of this InvitationUpdateParameters.  # noqa: E501

        List of teams the user is assigned to.  # noqa: E501

        :return: The team_ids of this InvitationUpdateParameters.  # noqa: E501
        :rtype: list[str]
        """
        return self._team_ids

    @team_ids.setter
    def team_ids(self, team_ids):
        """Sets the team_ids of this InvitationUpdateParameters.

        List of teams the user is assigned to.  # noqa: E501

        :param team_ids: The team_ids of this InvitationUpdateParameters.  # noqa: E501
        :type: list[str]
        """

        self._team_ids = team_ids

    @property
    def default_locale_codes(self):
        """Gets the default_locale_codes of this InvitationUpdateParameters.  # noqa: E501

        List of default locales for the user.  # noqa: E501

        :return: The default_locale_codes of this InvitationUpdateParameters.  # noqa: E501
        :rtype: list[str]
        """
        return self._default_locale_codes

    @default_locale_codes.setter
    def default_locale_codes(self, default_locale_codes):
        """Sets the default_locale_codes of this InvitationUpdateParameters.

        List of default locales for the user.  # noqa: E501

        :param default_locale_codes: The default_locale_codes of this InvitationUpdateParameters.  # noqa: E501
        :type: list[str]
        """

        self._default_locale_codes = default_locale_codes

    @property
    def permissions(self):
        """Gets the permissions of this InvitationUpdateParameters.  # noqa: E501

        Additional permissions depending on invitation role.  # noqa: E501

        :return: The permissions of this InvitationUpdateParameters.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._permissions

    @permissions.setter
    def permissions(self, permissions):
        """Sets the permissions of this InvitationUpdateParameters.

        Additional permissions depending on invitation role.  # noqa: E501

        :param permissions: The permissions of this InvitationUpdateParameters.  # noqa: E501
        :type: dict(str, str)
        """

        self._permissions = permissions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InvitationUpdateParameters):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InvitationUpdateParameters):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import phrase_api
from phrase_api.models.comment import Comment  # noqa: E501
from phrase_api.rest import ApiException

class TestComment(unittest.TestCase):
    """Comment unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Comment
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = phrase_api.models.comment.Comment()  # noqa: E501
        if include_optional :
            return Comment(
                id = '0', 
                message = '0', 
                user = phrase_api.models.user_preview.user_preview(
                    id = '0', 
                    username = '0', 
                    name = '0', 
                    gravatar_uid = '0', ), 
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                mentioned_users = [
                    phrase_api.models.user_preview.user_preview(
                        id = '0', 
                        username = '0', 
                        name = '0', 
                        gravatar_uid = '0', )
                    ]
            )
        else :
            return Comment(
        )

    def testComment(self):
        """Test Comment"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from phrase_api.configuration import Configuration


class Distribution(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'name': 'str',
        'project': 'ProjectShort',
        'platforms': 'list[str]',
        'locales': 'list[LocalePreview]',
        'releases': 'list[ReleasePreview]',
        'created_at': 'datetime',
        'deleted_at': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'project': 'project',
        'platforms': 'platforms',
        'locales': 'locales',
        'releases': 'releases',
        'created_at': 'created_at',
        'deleted_at': 'deleted_at'
    }

    def __init__(self, id=None, name=None, project=None, platforms=None, locales=None, releases=None, created_at=None, deleted_at=None, local_vars_configuration=None):  # noqa: E501
        """Distribution - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._name = None
        self._project = None
        self._platforms = None
        self._locales = None
        self._releases = None
        self._created_at = None
        self._deleted_at = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if project is not None:
            self.project = project
        if platforms is not None:
            self.platforms = platforms
        if locales is not None:
            self.locales = locales
        if releases is not None:
            self.releases = releases
        if created_at is not None:
            self.created_at = created_at
        if deleted_at is not None:
            self.deleted_at = deleted_at

    @property
    def id(self):
        """Gets the id of this Distribution.  # noqa: E501


        :return: The id of this Distribution.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Distribution.


        :param id: The id of this Distribution.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this Distribution.  # noqa: E501


        :return: The name of this Distribution.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Distribution.


        :param name: The name of this Distribution.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def project(self):
        """Gets the project of this Distribution.  # noqa: E501


        :return: The project of this Distribution.  # noqa: E501
        :rtype: ProjectShort
        """
        return self._project

    @project.setter
    def project(self, project):
        """Sets the project of this Distribution.


        :param project: The project of this Distribution.  # noqa: E501
        :type: ProjectShort
        """

        self._project = project

    @property
    def platforms(self):
        """Gets the platforms of this Distribution.  # noqa: E501


        :return: The platforms of this Distribution.  # noqa: E501
        :rtype: list[str]
        """
        return self._platforms

    @platforms.setter
    def platforms(self, platforms):
        """Sets the platforms of this Distribution.


        :param platforms: The platforms of this Distribution.  # noqa: E501
        :type: list[str]
        """

        self._platforms = platforms

    @property
    def locales(self):
        """Gets the locales of this Distribution.  # noqa: E501


        :return: The locales of this Distribution.  # noqa: E501
        :rtype: list[LocalePreview]
        """
        return self._locales

    @locales.setter
    def locales(self, locales):
        """Sets the locales of this Distribution.


        :param locales: The locales of this Distribution.  # noqa: E501
        :type: list[LocalePreview]
        """

        self._locales = locales

    @property
    def releases(self):
        """Gets the releases of this Distribution.  # noqa: E501


        :return: The releases of this Distribution.  # noqa: E501
        :rtype: list[ReleasePreview]
        """
        return self._releases

    @releases.setter
    def releases(self, releases):
        """Sets the releases of this Distribution.


        :param releases: The releases of this Distribution.  # noqa: E501
        :type: list[ReleasePreview]
        """

        self._releases = releases

    @property
    def created_at(self):
        """Gets the created_at of this Distribution.  # noqa: E501


        :return: The created_at of this Distribution.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Distribution.


        :param created_at: The created_at of this Distribution.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def deleted_at(self):
        """Gets the deleted_at of this Distribution.  # noqa: E501


        :return: The deleted_at of this Distribution.  # noqa: E501
        :rtype: datetime
        """
        return self._deleted_at

    @deleted_at.setter
    def deleted_at(self, deleted_at):
        """Sets the deleted_at of this Distribution.


        :param deleted_at: The deleted_at of this Distribution.  # noqa: E501
        :type: datetime
        """

        self._deleted_at = deleted_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Distribution):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Distribution):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import phrase_api
from phrase_api.api.accounts_api import AccountsApi  # noqa: E501
from phrase_api.rest import ApiException


class TestAccountsApi(unittest.TestCase):
    """AccountsApi unit test stubs"""

    def setUp(self):
        self.api = phrase_api.api.accounts_api.AccountsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_account_show(self):
        """Test case for account_show

        Get a single account  # noqa: E501
        """
        pass

    def test_accounts_list(self):
        """Test case for accounts_list

        List accounts  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import phrase_api
from phrase_api.api.locales_api import LocalesApi  # noqa: E501
from phrase_api.rest import ApiException


class TestLocalesApi(unittest.TestCase):
    """LocalesApi unit test stubs"""

    def setUp(self):
        self.api = phrase_api.api.locales_api.LocalesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_account_locales(self):
        """Test case for account_locales

        List locales used in account  # noqa: E501
        """
        pass

    def test_locale_create(self):
        """Test case for locale_create

        Create a locale  # noqa: E501
        """
        pass

    def test_locale_delete(self):
        """Test case for locale_delete

        Delete a locale  # noqa: E501
        """
        pass

    def test_locale_download(self):
        """Test case for locale_download

        Download a locale  # noqa: E501
        """
        pass

    def test_locale_show(self):
        """Test case for locale_show

        Get a single locale  # noqa: E501
        """
        pass

    def test_locale_update(self):
        """Test case for locale_update

        Update a locale  # noqa: E501
        """
        pass

    def test_locales_list(self):
        """Test case for locales_list

        List locales  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import phrase_api
from phrase_api.models.translation_version_with_user1 import TranslationVersionWithUser1  # noqa: E501
from phrase_api.rest import ApiException

class TestTranslationVersionWithUser1(unittest.TestCase):
    """TranslationVersionWithUser1 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test TranslationVersionWithUser1
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = phrase_api.models.translation_version_with_user1.TranslationVersionWithUser1()  # noqa: E501
        if include_optional :
            return TranslationVersionWithUser1(
                user = phrase_api.models.user_preview.user_preview(
                    id = '0', 
                    username = '0', 
                    name = '0', 
                    gravatar_uid = '0', )
            )
        else :
            return TranslationVersionWithUser1(
        )

    def testTranslationVersionWithUser1(self):
        """Test TranslationVersionWithUser1"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from phrase_api.api_client import ApiClient
from phrase_api.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class KeysApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def key_create(self, project_id, key_create_parameters, **kwargs):  # noqa: E501
        """Create a key  # noqa: E501

        Create a new key.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.key_create(project_id, key_create_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param KeyCreateParameters key_create_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: TranslationKeyDetails
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.key_create_with_http_info(project_id, key_create_parameters, **kwargs)  # noqa: E501

    def key_create_with_http_info(self, project_id, key_create_parameters, **kwargs):  # noqa: E501
        """Create a key  # noqa: E501

        Create a new key.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.key_create_with_http_info(project_id, key_create_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param KeyCreateParameters key_create_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(TranslationKeyDetails, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_id',
            'key_create_parameters',
            'x_phrase_app_otp'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method key_create" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['project_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `project_id` when calling `key_create`")  # noqa: E501
        # verify the required parameter 'key_create_parameters' is set
        if self.api_client.client_side_validation and ('key_create_parameters' not in local_var_params or  # noqa: E501
                                                        local_var_params['key_create_parameters'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `key_create_parameters` when calling `key_create`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in local_var_params:
            path_params['project_id'] = local_var_params['project_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'key_create_parameters' in local_var_params:
            body_params = local_var_params['key_create_parameters']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_id}/keys', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TranslationKeyDetails',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def key_delete(self, project_id, id, **kwargs):  # noqa: E501
        """Delete a key  # noqa: E501

        Delete an existing key.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.key_delete(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param str branch: specify the branch to use
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.key_delete_with_http_info(project_id, id, **kwargs)  # noqa: E501

    def key_delete_with_http_info(self, project_id, id, **kwargs):  # noqa: E501
        """Delete a key  # noqa: E501

        Delete an existing key.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.key_delete_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param str branch: specify the branch to use
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_id',
            'id',
            'x_phrase_app_otp',
            'branch'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method key_delete" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['project_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `project_id` when calling `key_delete`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `key_delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in local_var_params:
            path_params['project_id'] = local_var_params['project_id']  # noqa: E501
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []
        if 'branch' in local_var_params and local_var_params['branch'] is not None:  # noqa: E501
            query_params.append(('branch', local_var_params['branch']))  # noqa: E501

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_id}/keys/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def key_show(self, project_id, id, **kwargs):  # noqa: E501
        """Get a single key  # noqa: E501

        Get details on a single key for a given project.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.key_show(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param str branch: specify the branch to use
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: TranslationKeyDetails
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.key_show_with_http_info(project_id, id, **kwargs)  # noqa: E501

    def key_show_with_http_info(self, project_id, id, **kwargs):  # noqa: E501
        """Get a single key  # noqa: E501

        Get details on a single key for a given project.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.key_show_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param str branch: specify the branch to use
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(TranslationKeyDetails, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_id',
            'id',
            'x_phrase_app_otp',
            'branch'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method key_show" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['project_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `project_id` when calling `key_show`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `key_show`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in local_var_params:
            path_params['project_id'] = local_var_params['project_id']  # noqa: E501
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []
        if 'branch' in local_var_params and local_var_params['branch'] is not None:  # noqa: E501
            query_params.append(('branch', local_var_params['branch']))  # noqa: E501

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_id}/keys/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TranslationKeyDetails',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def key_update(self, project_id, id, key_update_parameters, **kwargs):  # noqa: E501
        """Update a key  # noqa: E501

        Update an existing key.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.key_update(project_id, id, key_update_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param KeyUpdateParameters key_update_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: TranslationKeyDetails
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.key_update_with_http_info(project_id, id, key_update_parameters, **kwargs)  # noqa: E501

    def key_update_with_http_info(self, project_id, id, key_update_parameters, **kwargs):  # noqa: E501
        """Update a key  # noqa: E501

        Update an existing key.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.key_update_with_http_info(project_id, id, key_update_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param KeyUpdateParameters key_update_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(TranslationKeyDetails, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_id',
            'id',
            'key_update_parameters',
            'x_phrase_app_otp'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method key_update" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['project_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `project_id` when calling `key_update`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `key_update`")  # noqa: E501
        # verify the required parameter 'key_update_parameters' is set
        if self.api_client.client_side_validation and ('key_update_parameters' not in local_var_params or  # noqa: E501
                                                        local_var_params['key_update_parameters'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `key_update_parameters` when calling `key_update`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in local_var_params:
            path_params['project_id'] = local_var_params['project_id']  # noqa: E501
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'key_update_parameters' in local_var_params:
            body_params = local_var_params['key_update_parameters']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_id}/keys/{id}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TranslationKeyDetails',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def keys_delete_collection(self, project_id, **kwargs):  # noqa: E501
        """Delete collection of keys  # noqa: E501

        Delete all keys matching query. Same constraints as list. Please limit the number of affected keys to about 1,000 as you might experience timeouts otherwise.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.keys_delete_collection(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param str branch: specify the branch to use
        :param str q: Specify a query to do broad search for keys by name (including wildcards).<br><br> The following qualifiers are also supported in the search term:<br> <ul>   <li><code>ids:key_id,...</code> for queries on a comma-separated list of ids</li>   <li><code>name:key_name</code> for text queries on exact key names - spaces, commas, and colons  need to be escaped with double backslashes</li>   <li><code>tags:tag_name</code> to filter for keys with certain tags</li>   <li><code>translated:{true|false}</code> for translation status (also requires <code>locale_id</code> to be specified)</li>   <li><code>updated_at:{>=|<=}2013-02-21T00:00:00Z</code> for date range queries</li>   <li><code>unmentioned_in_upload:upload_id</code> to filter keys unmentioned within upload</li> </ul> Find more examples <a href=\"#overview--usage-examples\">here</a>. 
        :param str locale_id: Locale used to determine the translation state of a key when filtering for untranslated or translated keys.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: AffectedResources
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.keys_delete_collection_with_http_info(project_id, **kwargs)  # noqa: E501

    def keys_delete_collection_with_http_info(self, project_id, **kwargs):  # noqa: E501
        """Delete collection of keys  # noqa: E501

        Delete all keys matching query. Same constraints as list. Please limit the number of affected keys to about 1,000 as you might experience timeouts otherwise.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.keys_delete_collection_with_http_info(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param str branch: specify the branch to use
        :param str q: Specify a query to do broad search for keys by name (including wildcards).<br><br> The following qualifiers are also supported in the search term:<br> <ul>   <li><code>ids:key_id,...</code> for queries on a comma-separated list of ids</li>   <li><code>name:key_name</code> for text queries on exact key names - spaces, commas, and colons  need to be escaped with double backslashes</li>   <li><code>tags:tag_name</code> to filter for keys with certain tags</li>   <li><code>translated:{true|false}</code> for translation status (also requires <code>locale_id</code> to be specified)</li>   <li><code>updated_at:{>=|<=}2013-02-21T00:00:00Z</code> for date range queries</li>   <li><code>unmentioned_in_upload:upload_id</code> to filter keys unmentioned within upload</li> </ul> Find more examples <a href=\"#overview--usage-examples\">here</a>. 
        :param str locale_id: Locale used to determine the translation state of a key when filtering for untranslated or translated keys.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(AffectedResources, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_id',
            'x_phrase_app_otp',
            'branch',
            'q',
            'locale_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method keys_delete_collection" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['project_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `project_id` when calling `keys_delete_collection`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in local_var_params:
            path_params['project_id'] = local_var_params['project_id']  # noqa: E501

        query_params = []
        if 'branch' in local_var_params and local_var_params['branch'] is not None:  # noqa: E501
            query_params.append(('branch', local_var_params['branch']))  # noqa: E501
        if 'q' in local_var_params and local_var_params['q'] is not None:  # noqa: E501
            query_params.append(('q', local_var_params['q']))  # noqa: E501
        if 'locale_id' in local_var_params and local_var_params['locale_id'] is not None:  # noqa: E501
            query_params.append(('locale_id', local_var_params['locale_id']))  # noqa: E501

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_id}/keys', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AffectedResources',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def keys_exclude(self, project_id, keys_exclude_parameters, **kwargs):  # noqa: E501
        """Exclude a locale on a collection of keys  # noqa: E501

        Exclude a locale on keys matching query. Same constraints as list.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.keys_exclude(project_id, keys_exclude_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param KeysExcludeParameters keys_exclude_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: AffectedResources
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.keys_exclude_with_http_info(project_id, keys_exclude_parameters, **kwargs)  # noqa: E501

    def keys_exclude_with_http_info(self, project_id, keys_exclude_parameters, **kwargs):  # noqa: E501
        """Exclude a locale on a collection of keys  # noqa: E501

        Exclude a locale on keys matching query. Same constraints as list.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.keys_exclude_with_http_info(project_id, keys_exclude_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param KeysExcludeParameters keys_exclude_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(AffectedResources, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_id',
            'keys_exclude_parameters',
            'x_phrase_app_otp'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method keys_exclude" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['project_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `project_id` when calling `keys_exclude`")  # noqa: E501
        # verify the required parameter 'keys_exclude_parameters' is set
        if self.api_client.client_side_validation and ('keys_exclude_parameters' not in local_var_params or  # noqa: E501
                                                        local_var_params['keys_exclude_parameters'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `keys_exclude_parameters` when calling `keys_exclude`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in local_var_params:
            path_params['project_id'] = local_var_params['project_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'keys_exclude_parameters' in local_var_params:
            body_params = local_var_params['keys_exclude_parameters']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_id}/keys/exclude', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AffectedResources',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def keys_include(self, project_id, keys_include_parameters, **kwargs):  # noqa: E501
        """Include a locale on a collection of keys  # noqa: E501

        Include a locale on keys matching query. Same constraints as list.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.keys_include(project_id, keys_include_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param KeysIncludeParameters keys_include_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: AffectedResources
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.keys_include_with_http_info(project_id, keys_include_parameters, **kwargs)  # noqa: E501

    def keys_include_with_http_info(self, project_id, keys_include_parameters, **kwargs):  # noqa: E501
        """Include a locale on a collection of keys  # noqa: E501

        Include a locale on keys matching query. Same constraints as list.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.keys_include_with_http_info(project_id, keys_include_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param KeysIncludeParameters keys_include_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(AffectedResources, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_id',
            'keys_include_parameters',
            'x_phrase_app_otp'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method keys_include" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['project_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `project_id` when calling `keys_include`")  # noqa: E501
        # verify the required parameter 'keys_include_parameters' is set
        if self.api_client.client_side_validation and ('keys_include_parameters' not in local_var_params or  # noqa: E501
                                                        local_var_params['keys_include_parameters'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `keys_include_parameters` when calling `keys_include`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in local_var_params:
            path_params['project_id'] = local_var_params['project_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'keys_include_parameters' in local_var_params:
            body_params = local_var_params['keys_include_parameters']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_id}/keys/include', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AffectedResources',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def keys_list(self, project_id, **kwargs):  # noqa: E501
        """List keys  # noqa: E501

        List all keys for the given project. Alternatively you can POST requests to /search.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.keys_list(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param int page: Page number
        :param int per_page: allows you to specify a page size up to 100 items, 25 by default
        :param str branch: specify the branch to use
        :param str sort: Sort by field. Can be one of: name, created_at, updated_at.
        :param str order: Order direction. Can be one of: asc, desc.
        :param str q: Specify a query to do broad search for keys by name (including wildcards).<br><br> The following qualifiers are also supported in the search term:<br> <ul>   <li><code>ids:key_id,...</code> for queries on a comma-separated list of ids</li>   <li><code>name:key_name</code> for text queries on exact key names - spaces, commas, and colons  need to be escaped with double backslashes</li>   <li><code>tags:tag_name</code> to filter for keys with certain tags</li>   <li><code>translated:{true|false}</code> for translation status (also requires <code>locale_id</code> to be specified)</li>   <li><code>updated_at:{>=|<=}2013-02-21T00:00:00Z</code> for date range queries</li>   <li><code>unmentioned_in_upload:upload_id</code> to filter keys unmentioned within upload</li> </ul> Find more examples <a href=\"#overview--usage-examples\">here</a>. 
        :param str locale_id: Locale used to determine the translation state of a key when filtering for untranslated or translated keys.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[TranslationKey]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.keys_list_with_http_info(project_id, **kwargs)  # noqa: E501

    def keys_list_with_http_info(self, project_id, **kwargs):  # noqa: E501
        """List keys  # noqa: E501

        List all keys for the given project. Alternatively you can POST requests to /search.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.keys_list_with_http_info(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param int page: Page number
        :param int per_page: allows you to specify a page size up to 100 items, 25 by default
        :param str branch: specify the branch to use
        :param str sort: Sort by field. Can be one of: name, created_at, updated_at.
        :param str order: Order direction. Can be one of: asc, desc.
        :param str q: Specify a query to do broad search for keys by name (including wildcards).<br><br> The following qualifiers are also supported in the search term:<br> <ul>   <li><code>ids:key_id,...</code> for queries on a comma-separated list of ids</li>   <li><code>name:key_name</code> for text queries on exact key names - spaces, commas, and colons  need to be escaped with double backslashes</li>   <li><code>tags:tag_name</code> to filter for keys with certain tags</li>   <li><code>translated:{true|false}</code> for translation status (also requires <code>locale_id</code> to be specified)</li>   <li><code>updated_at:{>=|<=}2013-02-21T00:00:00Z</code> for date range queries</li>   <li><code>unmentioned_in_upload:upload_id</code> to filter keys unmentioned within upload</li> </ul> Find more examples <a href=\"#overview--usage-examples\">here</a>. 
        :param str locale_id: Locale used to determine the translation state of a key when filtering for untranslated or translated keys.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[TranslationKey], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_id',
            'x_phrase_app_otp',
            'page',
            'per_page',
            'branch',
            'sort',
            'order',
            'q',
            'locale_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method keys_list" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['project_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `project_id` when calling `keys_list`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in local_var_params:
            path_params['project_id'] = local_var_params['project_id']  # noqa: E501

        query_params = []
        if 'page' in local_var_params and local_var_params['page'] is not None:  # noqa: E501
            query_params.append(('page', local_var_params['page']))  # noqa: E501
        if 'per_page' in local_var_params and local_var_params['per_page'] is not None:  # noqa: E501
            query_params.append(('per_page', local_var_params['per_page']))  # noqa: E501
        if 'branch' in local_var_params and local_var_params['branch'] is not None:  # noqa: E501
            query_params.append(('branch', local_var_params['branch']))  # noqa: E501
        if 'sort' in local_var_params and local_var_params['sort'] is not None:  # noqa: E501
            query_params.append(('sort', local_var_params['sort']))  # noqa: E501
        if 'order' in local_var_params and local_var_params['order'] is not None:  # noqa: E501
            query_params.append(('order', local_var_params['order']))  # noqa: E501
        if 'q' in local_var_params and local_var_params['q'] is not None:  # noqa: E501
            query_params.append(('q', local_var_params['q']))  # noqa: E501
        if 'locale_id' in local_var_params and local_var_params['locale_id'] is not None:  # noqa: E501
            query_params.append(('locale_id', local_var_params['locale_id']))  # noqa: E501

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_id}/keys', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[TranslationKey]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def keys_search(self, project_id, keys_search_parameters, **kwargs):  # noqa: E501
        """Search keys  # noqa: E501

        Search keys for the given project matching query.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.keys_search(project_id, keys_search_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param KeysSearchParameters keys_search_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param int page: Page number
        :param int per_page: allows you to specify a page size up to 100 items, 25 by default
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[TranslationKey]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.keys_search_with_http_info(project_id, keys_search_parameters, **kwargs)  # noqa: E501

    def keys_search_with_http_info(self, project_id, keys_search_parameters, **kwargs):  # noqa: E501
        """Search keys  # noqa: E501

        Search keys for the given project matching query.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.keys_search_with_http_info(project_id, keys_search_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param KeysSearchParameters keys_search_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param int page: Page number
        :param int per_page: allows you to specify a page size up to 100 items, 25 by default
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[TranslationKey], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_id',
            'keys_search_parameters',
            'x_phrase_app_otp',
            'page',
            'per_page'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method keys_search" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['project_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `project_id` when calling `keys_search`")  # noqa: E501
        # verify the required parameter 'keys_search_parameters' is set
        if self.api_client.client_side_validation and ('keys_search_parameters' not in local_var_params or  # noqa: E501
                                                        local_var_params['keys_search_parameters'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `keys_search_parameters` when calling `keys_search`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in local_var_params:
            path_params['project_id'] = local_var_params['project_id']  # noqa: E501

        query_params = []
        if 'page' in local_var_params and local_var_params['page'] is not None:  # noqa: E501
            query_params.append(('page', local_var_params['page']))  # noqa: E501
        if 'per_page' in local_var_params and local_var_params['per_page'] is not None:  # noqa: E501
            query_params.append(('per_page', local_var_params['per_page']))  # noqa: E501

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'keys_search_parameters' in local_var_params:
            body_params = local_var_params['keys_search_parameters']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_id}/keys/search', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[TranslationKey]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def keys_tag(self, project_id, keys_tag_parameters, **kwargs):  # noqa: E501
        """Add tags to collection of keys  # noqa: E501

        Tags all keys matching query. Same constraints as list.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.keys_tag(project_id, keys_tag_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param KeysTagParameters keys_tag_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: AffectedResources
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.keys_tag_with_http_info(project_id, keys_tag_parameters, **kwargs)  # noqa: E501

    def keys_tag_with_http_info(self, project_id, keys_tag_parameters, **kwargs):  # noqa: E501
        """Add tags to collection of keys  # noqa: E501

        Tags all keys matching query. Same constraints as list.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.keys_tag_with_http_info(project_id, keys_tag_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param KeysTagParameters keys_tag_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(AffectedResources, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_id',
            'keys_tag_parameters',
            'x_phrase_app_otp'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method keys_tag" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['project_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `project_id` when calling `keys_tag`")  # noqa: E501
        # verify the required parameter 'keys_tag_parameters' is set
        if self.api_client.client_side_validation and ('keys_tag_parameters' not in local_var_params or  # noqa: E501
                                                        local_var_params['keys_tag_parameters'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `keys_tag_parameters` when calling `keys_tag`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in local_var_params:
            path_params['project_id'] = local_var_params['project_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'keys_tag_parameters' in local_var_params:
            body_params = local_var_params['keys_tag_parameters']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_id}/keys/tag', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AffectedResources',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def keys_untag(self, project_id, keys_untag_parameters, **kwargs):  # noqa: E501
        """Remove tags from collection of keys  # noqa: E501

        Removes specified tags from keys matching query.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.keys_untag(project_id, keys_untag_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param KeysUntagParameters keys_untag_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: AffectedResources
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.keys_untag_with_http_info(project_id, keys_untag_parameters, **kwargs)  # noqa: E501

    def keys_untag_with_http_info(self, project_id, keys_untag_parameters, **kwargs):  # noqa: E501
        """Remove tags from collection of keys  # noqa: E501

        Removes specified tags from keys matching query.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.keys_untag_with_http_info(project_id, keys_untag_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param KeysUntagParameters keys_untag_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(AffectedResources, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_id',
            'keys_untag_parameters',
            'x_phrase_app_otp'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method keys_untag" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['project_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `project_id` when calling `keys_untag`")  # noqa: E501
        # verify the required parameter 'keys_untag_parameters' is set
        if self.api_client.client_side_validation and ('keys_untag_parameters' not in local_var_params or  # noqa: E501
                                                        local_var_params['keys_untag_parameters'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `keys_untag_parameters` when calling `keys_untag`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in local_var_params:
            path_params['project_id'] = local_var_params['project_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'keys_untag_parameters' in local_var_params:
            body_params = local_var_params['keys_untag_parameters']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_id}/keys/untag', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AffectedResources',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import phrase_api
from phrase_api.models.account_search_result import AccountSearchResult  # noqa: E501
from phrase_api.rest import ApiException

class TestAccountSearchResult(unittest.TestCase):
    """AccountSearchResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test AccountSearchResult
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = phrase_api.models.account_search_result.AccountSearchResult()  # noqa: E501
        if include_optional :
            return AccountSearchResult(
                query = '0', 
                excerpt = '0', 
                key = phrase_api.models.key_preview.key_preview(
                    id = '0', 
                    name = '0', 
                    plural = True, ), 
                locale = {"id":"abcd1234cdef1234abcd1234cdef1234","name":"English","code":"en-GB"}, 
                project = {"id":"abcd1234cdef1234abcd1234cdef1234","name":"My Android Project","slug":"android_project","main_format":"xml","project_image_url":"http://assets.example.com/project.png","account":"account","space":"space","created_at":"2015-01-28T09:52:53Z","updated_at":"2015-01-28T09:52:53Z"}, 
                translation = {"id":"abcd1234cdef1234abcd1234cdef1234","content":"My translation","unverified":false,"excluded":false,"plural_suffix":"","key":{"id":"abcd1234cdef1234abcd1234cdef1234","name":"home.index.headline","plural":false},"locale":{"id":"abcd1234cdef1234abcd1234cdef1234","name":"de","code":"de-DE"},"placeholders":["%{count}"],"state":"translated","created_at":"2015-01-28T09:52:53Z","updated_at":"2015-01-28T09:52:53Z"}, 
                other_translations = [
                    {"id":"abcd1234cdef1234abcd1234cdef1234","content":"My translation","unverified":false,"excluded":false,"plural_suffix":"","key":{"id":"abcd1234cdef1234abcd1234cdef1234","name":"home.index.headline","plural":false},"locale":{"id":"abcd1234cdef1234abcd1234cdef1234","name":"de","code":"de-DE"},"placeholders":["%{count}"],"state":"translated","created_at":"2015-01-28T09:52:53Z","updated_at":"2015-01-28T09:52:53Z"}
                    ]
            )
        else :
            return AccountSearchResult(
        )

    def testAccountSearchResult(self):
        """Test AccountSearchResult"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import phrase_api
from phrase_api.api.authorizations_api import AuthorizationsApi  # noqa: E501
from phrase_api.rest import ApiException


class TestAuthorizationsApi(unittest.TestCase):
    """AuthorizationsApi unit test stubs"""

    def setUp(self):
        self.api = phrase_api.api.authorizations_api.AuthorizationsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_authorization_create(self):
        """Test case for authorization_create

        Create an authorization  # noqa: E501
        """
        pass

    def test_authorization_delete(self):
        """Test case for authorization_delete

        Delete an authorization  # noqa: E501
        """
        pass

    def test_authorization_show(self):
        """Test case for authorization_show

        Get a single authorization  # noqa: E501
        """
        pass

    def test_authorization_update(self):
        """Test case for authorization_update

        Update an authorization  # noqa: E501
        """
        pass

    def test_authorizations_list(self):
        """Test case for authorizations_list

        List authorizations  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import phrase_api
from phrase_api.models.screenshot_marker import ScreenshotMarker  # noqa: E501
from phrase_api.rest import ApiException

class TestScreenshotMarker(unittest.TestCase):
    """ScreenshotMarker unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ScreenshotMarker
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = phrase_api.models.screenshot_marker.ScreenshotMarker()  # noqa: E501
        if include_optional :
            return ScreenshotMarker(
                id = '0', 
                presentation = '0', 
                presentation_type = '0', 
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                translation_key = {"id":"abcd1234cdef1234abcd1234cdef1234","name":"home.index.headline","description":"My description for this key...","name_hash":"1b31d2580ce324f246f66b3be00ed399","plural":false,"tags":["awesome-feature","needs-proofreading"],"data_type":"string","created_at":"2015-01-28T09:52:53Z","updated_at":"2015-01-28T09:52:53Z"}
            )
        else :
            return ScreenshotMarker(
        )

    def testScreenshotMarker(self):
        """Test ScreenshotMarker"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import phrase_api
from phrase_api.api.branches_api import BranchesApi  # noqa: E501
from phrase_api.rest import ApiException


class TestBranchesApi(unittest.TestCase):
    """BranchesApi unit test stubs"""

    def setUp(self):
        self.api = phrase_api.api.branches_api.BranchesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_branch_compare(self):
        """Test case for branch_compare

        Compare branches  # noqa: E501
        """
        pass

    def test_branch_create(self):
        """Test case for branch_create

        Create a branch  # noqa: E501
        """
        pass

    def test_branch_delete(self):
        """Test case for branch_delete

        Delete a branch  # noqa: E501
        """
        pass

    def test_branch_merge(self):
        """Test case for branch_merge

        Merge a branch  # noqa: E501
        """
        pass

    def test_branch_show(self):
        """Test case for branch_show

        Get a single branch  # noqa: E501
        """
        pass

    def test_branch_update(self):
        """Test case for branch_update

        Update a branch  # noqa: E501
        """
        pass

    def test_branches_list(self):
        """Test case for branches_list

        List branches  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from phrase_api.configuration import Configuration


class ReleasePreview(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'version': 'int',
        'app_min_version': 'str',
        'app_max_version': 'str',
        'description': 'str',
        'platforms': 'list[str]',
        'environments': 'list[str]',
        'locale_codes': 'list[str]',
        'project': 'ProjectShort',
        'created_at': 'datetime',
        'updated_at': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'version': 'version',
        'app_min_version': 'app_min_version',
        'app_max_version': 'app_max_version',
        'description': 'description',
        'platforms': 'platforms',
        'environments': 'environments',
        'locale_codes': 'locale_codes',
        'project': 'project',
        'created_at': 'created_at',
        'updated_at': 'updated_at'
    }

    def __init__(self, id=None, version=None, app_min_version=None, app_max_version=None, description=None, platforms=None, environments=None, locale_codes=None, project=None, created_at=None, updated_at=None, local_vars_configuration=None):  # noqa: E501
        """ReleasePreview - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._version = None
        self._app_min_version = None
        self._app_max_version = None
        self._description = None
        self._platforms = None
        self._environments = None
        self._locale_codes = None
        self._project = None
        self._created_at = None
        self._updated_at = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if version is not None:
            self.version = version
        if app_min_version is not None:
            self.app_min_version = app_min_version
        if app_max_version is not None:
            self.app_max_version = app_max_version
        if description is not None:
            self.description = description
        if platforms is not None:
            self.platforms = platforms
        if environments is not None:
            self.environments = environments
        if locale_codes is not None:
            self.locale_codes = locale_codes
        if project is not None:
            self.project = project
        if created_at is not None:
            self.created_at = created_at
        if updated_at is not None:
            self.updated_at = updated_at

    @property
    def id(self):
        """Gets the id of this ReleasePreview.  # noqa: E501


        :return: The id of this ReleasePreview.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ReleasePreview.


        :param id: The id of this ReleasePreview.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def version(self):
        """Gets the version of this ReleasePreview.  # noqa: E501


        :return: The version of this ReleasePreview.  # noqa: E501
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this ReleasePreview.


        :param version: The version of this ReleasePreview.  # noqa: E501
        :type: int
        """

        self._version = version

    @property
    def app_min_version(self):
        """Gets the app_min_version of this ReleasePreview.  # noqa: E501


        :return: The app_min_version of this ReleasePreview.  # noqa: E501
        :rtype: str
        """
        return self._app_min_version

    @app_min_version.setter
    def app_min_version(self, app_min_version):
        """Sets the app_min_version of this ReleasePreview.


        :param app_min_version: The app_min_version of this ReleasePreview.  # noqa: E501
        :type: str
        """

        self._app_min_version = app_min_version

    @property
    def app_max_version(self):
        """Gets the app_max_version of this ReleasePreview.  # noqa: E501


        :return: The app_max_version of this ReleasePreview.  # noqa: E501
        :rtype: str
        """
        return self._app_max_version

    @app_max_version.setter
    def app_max_version(self, app_max_version):
        """Sets the app_max_version of this ReleasePreview.


        :param app_max_version: The app_max_version of this ReleasePreview.  # noqa: E501
        :type: str
        """

        self._app_max_version = app_max_version

    @property
    def description(self):
        """Gets the description of this ReleasePreview.  # noqa: E501


        :return: The description of this ReleasePreview.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ReleasePreview.


        :param description: The description of this ReleasePreview.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def platforms(self):
        """Gets the platforms of this ReleasePreview.  # noqa: E501


        :return: The platforms of this ReleasePreview.  # noqa: E501
        :rtype: list[str]
        """
        return self._platforms

    @platforms.setter
    def platforms(self, platforms):
        """Sets the platforms of this ReleasePreview.


        :param platforms: The platforms of this ReleasePreview.  # noqa: E501
        :type: list[str]
        """

        self._platforms = platforms

    @property
    def environments(self):
        """Gets the environments of this ReleasePreview.  # noqa: E501


        :return: The environments of this ReleasePreview.  # noqa: E501
        :rtype: list[str]
        """
        return self._environments

    @environments.setter
    def environments(self, environments):
        """Sets the environments of this ReleasePreview.


        :param environments: The environments of this ReleasePreview.  # noqa: E501
        :type: list[str]
        """

        self._environments = environments

    @property
    def locale_codes(self):
        """Gets the locale_codes of this ReleasePreview.  # noqa: E501


        :return: The locale_codes of this ReleasePreview.  # noqa: E501
        :rtype: list[str]
        """
        return self._locale_codes

    @locale_codes.setter
    def locale_codes(self, locale_codes):
        """Sets the locale_codes of this ReleasePreview.


        :param locale_codes: The locale_codes of this ReleasePreview.  # noqa: E501
        :type: list[str]
        """

        self._locale_codes = locale_codes

    @property
    def project(self):
        """Gets the project of this ReleasePreview.  # noqa: E501


        :return: The project of this ReleasePreview.  # noqa: E501
        :rtype: ProjectShort
        """
        return self._project

    @project.setter
    def project(self, project):
        """Sets the project of this ReleasePreview.


        :param project: The project of this ReleasePreview.  # noqa: E501
        :type: ProjectShort
        """

        self._project = project

    @property
    def created_at(self):
        """Gets the created_at of this ReleasePreview.  # noqa: E501


        :return: The created_at of this ReleasePreview.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this ReleasePreview.


        :param created_at: The created_at of this ReleasePreview.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this ReleasePreview.  # noqa: E501


        :return: The updated_at of this ReleasePreview.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this ReleasePreview.


        :param updated_at: The updated_at of this ReleasePreview.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ReleasePreview):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ReleasePreview):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import phrase_api
from phrase_api.models.team import Team  # noqa: E501
from phrase_api.rest import ApiException

class TestTeam(unittest.TestCase):
    """Team unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Team
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = phrase_api.models.team.Team()  # noqa: E501
        if include_optional :
            return Team(
                id = '0', 
                name = '0', 
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                projects = [
                    {"id":"abcd1234cdef1234abcd1234cdef1234","name":"My Android Project","slug":"android_project","main_format":"xml","project_image_url":"http://assets.example.com/project.png","account":"account","space":"space","created_at":"2015-01-28T09:52:53Z","updated_at":"2015-01-28T09:52:53Z"}
                    ], 
                spaces = [
                    {"id":"2e7574e8f2372906a03110c2a7cfe671","name":"My first space","created_at":"2020-02-25T12:17:25Z","updated_at":"2020-03-13T14:46:57Z","projects_count":2,"projects":[{"id":"abcd1234cdef1234abcd1234cdef1234","name":"My Android Project","main_format":"xml","project_image_url":"http://assets.example.com/project.png","account":"account","created_at":"2015-01-28T09:52:53Z","updated_at":"2015-01-28T09:52:53Z"},{"id":"abcd11231fadef1234adacd1234cdef1234","name":"My IOS Project","main_format":"yml","project_image_url":"http://assets.example.com/project2.png","account":"account","created_at":"2015-01-28T09:52:53Z","updated_at":"2015-01-28T09:52:53Z"}]}
                    ], 
                users = [
                    phrase_api.models.user_preview.user_preview(
                        id = '0', 
                        username = '0', 
                        name = '0', 
                        gravatar_uid = '0', )
                    ]
            )
        else :
            return Team(
        )

    def testTeam(self):
        """Test Team"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import phrase_api
from phrase_api.models.project import Project  # noqa: E501
from phrase_api.rest import ApiException

class TestProject(unittest.TestCase):
    """Project unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Project
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = phrase_api.models.project.Project()  # noqa: E501
        if include_optional :
            return Project(
                id = '0', 
                name = '0', 
                slug = '0', 
                main_format = '0', 
                project_image_url = '0', 
                account = {"id":"abcd1234","name":"Company Account","slug":"company_account","company":"My Awesome Company","created_at":"2015-01-28T09:52:53Z","updated_at":"2015-01-28T09:52:53Z","company_logo_url":"http://assets.example.com/company_logo.png"}, 
                space = {"id":"2e7574e8f2372906a03110c2a7cfe671","name":"My first space","created_at":"2020-02-25T12:17:25Z","updated_at":"2020-03-13T14:46:57Z","projects_count":2}, 
                point_of_contact = phrase_api.models.user_preview.user_preview(
                    id = '0', 
                    username = '0', 
                    name = '0', 
                    gravatar_uid = '0', ), 
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else :
            return Project(
        )

    def testProject(self):
        """Test Project"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
